#!/bin/sh -x
# XPDX-License-Identifier: GPL-2.0+"

set -x
PATH=${PATH}:/usr/games

. /etc/pinball/pinball.env.sh ||:

export PINBALL_TABLE
export HOME
export XDG_RUNTIME_DIR

echo "# Configure display manager"
ls /sys/class/drm ||:
if [ ! -z ${XDG_RUNTIME_DIR} ]; then # Wayland
    ready=false
    while ! $ready; do
 	pidof weston && ready=true || sleep 10
    done

    if [ ! -z ${DISPLAY} ] ; then # XWayland
	ready=false
	while ! $ready; do
	    sleep 10
	    pidof Xwayland && ready=true || xterm -e "pidof xwayland" || sleep 10
	    pidof Xwayland && ready=true || Xwayland &
	    xterm -e "pidof xwayland" && ready=true || sleep 10
	done
    fi
elif [ ! -z ${DISPLAY} ] ; then # X11
    xsetroot -solid "purple" ||:
    [ ! -r "${PINBALL_XBM_IMAGE}" ] || xsetroot -bitmap  "${PINBALL_XBM_IMAGE}" 
    [ ! -r "${PINBALL_IMAGE}" ] || xloadimage -onroot "${PINBALL_IMAGE}"
    list=$(xrandr -q \
	       | grep '^[^ ].* ' | cut -d' ' -f1 | tail -n +2\
	       || echo "")
    # Guess primary screen
    if [ "" = "$PINBALL_SCREEN" ] ; then
	for screen in $list ; do
	    xrandr --output "${screen}" --primary ${PINBALL_XRANDR_ARGS} \
		&& PINBALL_SCREEN="$screen" \
		    || echo "log: skip ${screen}"
	done
    fi

    # Other screen(s)
    for screen in $list ; do
	if [ "${PINBALL_SCREEN}" != "$screen" ] ; then
	    xrandr --output "${screen}" --off
	    # TODO : It should be above but wont work
	    xrandr --output "${screen}" --right-of "${PINBALL_SCREEN}" --auto
	fi
    done

    xrandr --output "${PINBALL_SCREEN}" --primary ${PINBALL_XRANDR_ARGS} 
    xdotool mousemove 0 0
fi

# Check audio
aplay /usr/share/games/pinball/tux/lock.wav \
    || cat /proc/asound/card*/id | while read id ; do
	aplay /usr/share/games/pinball/tux/bump.wav \
	    && export ALSA_CARD="$id" \
	    && break ||:
    done


    
# Launching
aplay /usr/share/games/pinball/tux/loop.wav ||:
# TODO prefix with exec to skip shutdown
pinball

# Quitting
# TODO display maintenance images
aplay /usr/share/games/pinball/tux/gameover.wav ||:
sleep 100 # For maintenance stop xinit or pinball service
aplay /usr/share/games/pinball/tux/opentux.wav ||:
reboot # demo mode, comment for poweroff # TODO
poweroff
